@@ -8,7 +8,7 @@ class LogFileHandler(logging.Handler):
     def __init__(self, filename, format, **kwargs):
         assert format in ('json', 'plain'), \
             'format has to be either "json" or "plain"'
-        super(LogFileHandler, self).__init__(**kwargs)
+        logging.Handler.__init__(self, **kwargs)
         self.filename = filename
         self.formatter = (
             self.render_plain
@@ -23,7 +23,7 @@ class LogFileHandler(logging.Handler):
         for query in queries_list:
             for test in queries[query]:
                 fp.write("-- %s\n" % str(test))
-            fp.write(query + '\n')
+            fp.write(query.replace('\n', ' ').strip() + '\n')
 
     def render_json(self, fp, queries):
         json.dump(queries, fp)
