@@ -39,6 +39,22 @@ sql2
     eq_(expected, output.read())
 
 
+def test_render_plain_with_newline_in_sql():
+    handler = LogFileHandler('/tmp/foo', 'plain')
+    queries = {
+        'SELECT *\nFROM a INNER JOIN b\nUSING (id)\n': ['test1', 'test2'],
+    }
+    expected = """\
+-- test1
+-- test2
+SELECT * FROM a INNER JOIN b USING (id)
+"""
+    output = StringIO()
+    handler.formatter(output, queries)
+    output.seek(0)
+    eq_(expected, output.read())
+
+
 def test_render_json():
     handler = LogFileHandler('/tmp/foo', 'json')
     queries = {
